@@ -1,7 +1,7 @@
 from mpi4py import MPI as _MPI
 
 from jax import core
-from jax.core import Primitive
+from jax.core import Primitive, Tracer, Token
 from jax.interpreters import xla, batching
 from jax.lax import create_token
 from jax.lib import xla_client
@@ -17,7 +17,7 @@ from ..utils import (
 from ..decorators import translation_rule_cpu, translation_rule_gpu
 from ..validation import enforce_types
 from ..comm import get_default_comm
-from ..jax_compat import Tracer, Token
+from ..jax_compat import register_abstract_eval
 
 # The Jax primitive
 mpi_barrier_p = Primitive("barrier_mpi")  # Create the primitive
@@ -114,7 +114,7 @@ def mpi_barrier_batch_eval(in_args, batch_axes, comm):
 
 
 mpi_barrier_p.def_impl(mpi_barrier_impl)
-mpi_barrier_p.def_abstract_eval(mpi_barrier_abstract_eval)
+register_abstract_eval(mpi_barrier_p, mpi_barrier_abstract_eval)
 
 batching.primitive_batchers[mpi_barrier_p] = mpi_barrier_batch_eval
 
