@@ -2,7 +2,7 @@ import numpy as _np
 from mpi4py import MPI as _MPI
 
 from jax import abstract_arrays, core
-from jax.core import Primitive
+from jax.core import Primitive, Tracer, Token
 from jax.interpreters import xla
 from jax.lax import create_token
 from jax.lib import xla_client
@@ -21,7 +21,7 @@ from ..utils import (
 from ..decorators import translation_rule_cpu, translation_rule_gpu
 from ..validation import enforce_types
 from ..comm import get_default_comm
-from ..jax_compat import Tracer, Token
+from ..jax_compat import register_abstract_eval
 
 # The Jax primitive
 mpi_recv_p = Primitive("recv_mpi")  # Create the primitive
@@ -186,7 +186,7 @@ def mpi_recv_abstract_eval(xs, token, source, tag, comm, status):
 
 mpi_recv_p.multiple_results = True
 mpi_recv_p.def_impl(mpi_recv_impl)
-mpi_recv_p.def_abstract_eval(mpi_recv_abstract_eval)
+register_abstract_eval(mpi_recv_p, mpi_recv_abstract_eval)
 
 # assign to the primitive the correct encoder
 xla.backend_specific_translations["cpu"][mpi_recv_p] = mpi_recv_xla_encode_cpu
